@@ -16,6 +16,5 @@ __all__ = ['affinegap',
 from api import StaticDedupe, Dedupe
 from api import StaticRecordLink, RecordLink
 from api import StaticGazetteer, Gazetteer
-from core import randomPairs
+from core import randomPairs, randomPairsMatch, frozendict
 from convenience import consoleLabel, trainingDataDedupe, trainingDataLink, canonicalize
-from AsciiDammit import asciiDammit
